@@ -320,7 +320,7 @@ class AWSRuleInterface:
             str: The subject to use in notifications.
         """
         subject = self.__class__.__name__
-        subject_split = re.findall(r"[A-Z](?:[a-z]+|[A-Z]*(?=[A-Z]|$))", subject)
+        subject_split = re.findall(r"[0-9A-Z](?:[0-9a-z]+|[0-9A-Z]*(?=[0-9A-Z]|$))", subject)
         fixed_subject = " ".join(subject_split)
         return f"The Reflex Rule {fixed_subject} was triggered."
 
